==> maven-filtering_3.3.0.orig.tar.xz: maven-filtering-maven-filtering-3.3.0/src/main/java/org/apache/maven/shared/filtering/MavenFilteringException.java <==
package org.apache.maven.shared.filtering;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * @author Olivier Lamy
 */
public class MavenFilteringException
    extends Exception
{

    /**
     *
     */
    private static final long serialVersionUID = 1L;

    /**
     *
     */
    public MavenFilteringException()
    {
        // nothing
    }

    /**
     * @param message the message
     */
    public MavenFilteringException( String message )
    {
        super( message );
    }

    /**
     * @param cause the cause of the exception
     */
    public MavenFilteringException( Throwable cause )
    {
        super( cause );
    }

    /**
     * @param message a message
     * @param cause a worthy cause
     */
    public MavenFilteringException( String message, Throwable cause )
    {
        super( message, cause );
    }

}

==> maven-filtering_3.4.0.orig.tar.xz: maven-filtering-maven-filtering-3.4.0/src/main/java/org/apache/maven/shared/filtering/MavenFilteringException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.shared.filtering;

/**
 * @author Olivier Lamy
 */
public class MavenFilteringException extends Exception {

    /**
     *
     */
    private static final long serialVersionUID = 1L;

    /**
     *
     */
    public MavenFilteringException() {
        // nothing
    }

    /**
     * @param message the message
     */
    public MavenFilteringException(String message) {
        super(message);
    }

    /**
     * @param cause the cause of the exception
     */
    public MavenFilteringException(Throwable cause) {
        super(cause);
    }

    /**
     * @param message a message
     * @param cause a worthy cause
     */
    public MavenFilteringException(String message, Throwable cause) {
        super(message, cause);
    }
}
